/*
 * Copyright (c) 2013-2021 Meltytech, LLC
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
import QtQuick.Controls 2.12
import QtQuick.Layouts 1.12
import NeoEditor.Controls 1.0 as NeoEditor

ToolBar {
    property bool scrub: false //scrubButton.checked
    property color checkedColor: Qt.rgba(activePalette.highlight.r, activePalette.highlight.g, activePalette.highlight.b, 0.4)
    property alias scaleSlider: scaleSlider

    SystemPalette { id: activePalette }

    id: toolbar
    width: 200
    height: settings.smallIcons ? 25 : 33

    RowLayout {
        y: 2

        NeoEditor.ToolButton {
            id: menuButton
            implicitHeight: toolbar.height - 3
            implicitWidth: implicitHeight
            action: menuAction
            NeoEditor.HoverTip { text: qsTr('Display a menu of additional actions') }
            focusPolicy: Qt.NoFocus
        }
        Button { // separator
            enabled: false
            implicitWidth: 2
            implicitHeight: toolbar.height / 2
        }
//        NeoEditor.ToolButton {
//            implicitHeight: toolbar.height - 3
//            implicitWidth: implicitHeight
//            action: cutAction
//            NeoEditor.HoverTip { text: qsTr('Cut - Copy the current clip to the Source\nplayer and ripple delete it') }
//            focusPolicy: Qt.NoFocus
//        }
//        NeoEditor.ToolButton {
//            implicitHeight: toolbar.height - 3
//            implicitWidth: implicitHeight
//            action: copyAction
//            NeoEditor.HoverTip { text: qsTr('Copy - Copy the current clip to the Source player (C)') }
//            focusPolicy: Qt.NoFocus
//        }
//        NeoEditor.ToolButton {
//            implicitHeight: toolbar.height - 3
//            implicitWidth: implicitHeight
//            action: insertAction
//            NeoEditor.HoverTip { text: qsTr('Paste - Insert clip into the current track\nshifting following clips to the right (V)') }
//            focusPolicy: Qt.NoFocus
//        }
//        Button { // separator
//            enabled: false
//            implicitWidth: 2
//            implicitHeight: toolbar.height / 2
//        }
//        NeoEditor.ToolButton {
//            implicitHeight: toolbar.height - 3
//            implicitWidth: implicitHeight
//            action: appendAction
//            NeoEditor.HoverTip { text: qsTr('Append to the current track (A)') }
//            focusPolicy: Qt.NoFocus
//        }
//        NeoEditor.ToolButton {
//            implicitHeight: toolbar.height - 3
//            implicitWidth: implicitHeight
//            action: deleteAction
//            NeoEditor.HoverTip { text: qsTr('Ripple Delete - Remove current clip\nshifting following clips to the left (X)') }
//            focusPolicy: Qt.NoFocus
//        }
//        NeoEditor.ToolButton {
//            implicitHeight: toolbar.height - 3
//            implicitWidth: implicitHeight
//            action: liftAction
//            NeoEditor.HoverTip { text: qsTr('Lift - Remove current clip without\naffecting position of other clips (Z)') }
//            focusPolicy: Qt.NoFocus
//        }
//        NeoEditor.ToolButton {
//            implicitHeight: toolbar.height - 3
//            implicitWidth: implicitHeight
//            action: overwriteAction
//            NeoEditor.HoverTip { text: qsTr('Overwrite clip onto the current track (B)') }
//            focusPolicy: Qt.NoFocus
//        }
        NeoEditor.ToolButton {
            implicitHeight: toolbar.height - 3
            implicitWidth: implicitHeight
            action: splitAction
            NeoEditor.HoverTip { text: qsTr('Split At Playhead') + " (S)" }
            focusPolicy: Qt.NoFocus
        }
//        Button { // separator
//            enabled: false
//            implicitWidth: 2
//            implicitHeight: toolbar.height / 2
//        }
        NeoEditor.ToolButton {
            id: snapButton
            implicitHeight: toolbar.height - 3
            implicitWidth: implicitHeight
//            checked: settings.timelineSnap
            icon.name: 'snap'
            icon.source: 'qrc:///icons/oxygen/32x32/actions/snap.png'
            focusPolicy: Qt.NoFocus
            NeoEditor.HoverTip { text: qsTr('Merge with next clip')  + " (A)" }
            onClicked: timelineRoot.mergeClipWithNext()
        }
//        NeoEditor.ToolButton {
//            id: scrubButton
//            implicitHeight: toolbar.height - 3
//            implicitWidth: implicitHeight
//            checked: settings.timelineDragScrub
//            icon.name: 'scrub_drag'
//            icon.source: 'qrc:///icons/oxygen/32x32/actions/scrub_drag.png'
//            focusPolicy: Qt.NoFocus
//            NeoEditor.HoverTip { text: qsTr('Scrub while dragging') }
//            onClicked: settings.timelineDragScrub = !settings.timelineDragScrub
//        }
//        NeoEditor.ToolButton {
//            id: rippleButton
//            implicitHeight: toolbar.height - 3
//            implicitWidth: implicitHeight
//            checked: settings.timelineRipple
//            icon.name: 'target'
//            icon.source: 'qrc:///icons/oxygen/32x32/actions/target.png'
//            focusPolicy: Qt.NoFocus
//            NeoEditor.HoverTip { text: qsTr('Ripple trim and drop') }
//            onClicked: settings.timelineRipple = !settings.timelineRipple
//        }
//        NeoEditor.ToolButton {
//            id: rippleAllButton
//            implicitHeight: toolbar.height - 3
//            implicitWidth: implicitHeight
//            checked: settings.timelineRippleAllTracks
//            icon.name: 'ripple-all'
//            icon.source: 'qrc:///icons/oxygen/32x32/actions/ripple-all.png'
//            focusPolicy: Qt.NoFocus
//            NeoEditor.HoverTip { text: qsTr('Ripple edits across all tracks') }
//            onClicked: settings.timelineRippleAllTracks = !settings.timelineRippleAllTracks
//        }
        Button { // separator
            enabled: false
            implicitWidth: 2
            implicitHeight: toolbar.height / 2
        }
        NeoEditor.ToolButton {
            implicitHeight: toolbar.height - 3
            implicitWidth: implicitHeight
            action: zoomOutAction
            NeoEditor.HoverTip { text: qsTr("Zoom timeline out (-)") }
            focusPolicy: Qt.NoFocus
        }
        ZoomSlider {
            id: scaleSlider
        }
        NeoEditor.ToolButton {
            implicitHeight: toolbar.height - 3
            implicitWidth: implicitHeight
            action: zoomInAction
            NeoEditor.HoverTip { text: qsTr("Zoom timeline in (+)") }
            focusPolicy: Qt.NoFocus
        }
        NeoEditor.ToolButton {
            implicitHeight: toolbar.height - 3
            implicitWidth: implicitHeight
            action: zoomFitAction
            NeoEditor.HoverTip { text: qsTr('Zoom timeline to fit (0)') }
            focusPolicy: Qt.NoFocus
        }
        NeoEditor.ToolButton {
            implicitHeight: toolbar.height - 3
            implicitWidth: implicitHeight
            checked: settings.timelineRepeat
            icon.name: 'repeat-loop-sign'
            icon.source: 'qrc:///icons/repeat-loop-sign.png'
            focusPolicy: Qt.NoFocus
            NeoEditor.HoverTip { text: qsTr('Repeat after finish') }
            onClicked: settings.timelineRepeat = !settings.timelineRepeat
        }
    }

    Action {
        id: menuAction
        icon.name: 'show-menu'
        icon.source: 'qrc:///icons/oxygen/32x32/actions/show-menu.png'
        onTriggered: menu.popup()
    }

//    Action {
//        id: cutAction
//        icon.name: 'edit-cut'
//        icon.source: 'qrc:///icons/oxygen/32x32/actions/edit-cut.png'
//        enabled: timelineService.selection.length
//        onTriggered: timelineService.removeSelection(true)
//    }

//    Action {
//        id: copyAction
//        icon.name: 'edit-copy'
//        icon.source: 'qrc:///icons/oxygen/32x32/actions/edit-copy.png'
//        enabled: timelineService.selection.length
//        onTriggered: timelineService.copyClip(timelineService.selection[0].y, timelineService.selection[0].x)
//    }

//    Action {
//        id: insertAction
//        icon.name: 'edit-paste'
//        icon.source: 'qrc:///icons/oxygen/32x32/actions/edit-paste.png'
//        onTriggered: timelineService.insert(currentTrack)
//    }

//    Action {
//        id: appendAction
//        icon.name: 'list-add'
//        icon.source: 'qrc:///icons/oxygen/32x32/actions/list-add.png'
//        onTriggered: timelineService.append(currentTrack)
//    }

//    Action {
//        id: deleteAction
//        icon.name: 'list-remove'
//        icon.source: 'qrc:///icons/oxygen/32x32/actions/list-remove.png'
//        onTriggered: timelineService.removeSelection()
//   }

//    Action {
//        id: liftAction
//        icon.name: 'lift'
//        icon.source: 'qrc:///icons/oxygen/32x32/actions/lift.png'
//        onTriggered: timelineService.liftSelection()
//    }

//    Action {
//        id: overwriteAction
//        icon.name: 'overwrite'
//        icon.source: 'qrc:///icons/oxygen/32x32/actions/overwrite.png'
//        onTriggered: timelineService.overwrite(currentTrack)
//    }

    Action {
        id: splitAction
        icon.name: 'slice'
        icon.source: 'qrc:///icons/oxygen/32x32/actions/slice.png'
        onTriggered: /*Split only effects track*/ timelineService.splitClip(0)
    }

    Action {
        id: zoomOutAction
        icon.name: 'zoom-out'
        icon.source: 'qrc:///icons/oxygen/32x32/actions/zoom-out.png'
        onTriggered: timelineRoot.zoomOut()
    }

    Action {
        id: zoomInAction
        icon.name: 'zoom-in'
        icon.source: 'qrc:///icons/oxygen/32x32/actions/zoom-in.png'
        onTriggered: timelineRoot.zoomIn()
    }

    Action {
        id: zoomFitAction
        icon.name: 'zoom-fit-best'
        icon.source: 'qrc:///icons/oxygen/32x32/actions/zoom-fit-best.png'
        onTriggered: timelineRoot.zoomToFit()
    }
}
